PB.for.projection.f: A function calculated P/B for projection based on the climate...

Description Usage Arguments

View source: R/climate.scenario.functions.r

Description

A function calculated P/B for projection based on the climate scenario. It samples the residuals of the fitted relationship and adds one to each draw

Usage

1
PB.for.projection.f(PvsE, Eproj, add.residuals = add.resids)

Arguments

PvsE

The fitted PB vs E model object

Eproj

The matrix of E values for the projection. From running Eprojgamma.f

add.residuals

if yes=1, no=0. DO NOT USE ANY OTHER VALUE!! This formulation is faster because it avoids an if statement


duplisea/ccca documentation built on April 17, 2021, 2:31 a.m.