colramp.legend: A colour ramp legend for the E variable in a Kobe plot

Description Usage Arguments Examples

View source: R/plotting.data.ccf.functions.r

Description

A colour ramp legend for the E variable in a Kobe plot

Usage

 1
 2
 3
 4
 5
 6
 7
 8
 9
10
colramp.legend(
  col1 = "red",
  col2 = "blue",
  ncol,
  xleft,
  ybottom,
  xright,
  ytop,
  ...
)

Arguments

col1

the bottom colour of the colour ramp

ncol

the number of colours in the ramp (typically length(E))

xleft

a vector (or scalar) of left x positions

ybottom

a vector (or scalar) of bottom y positions

xright

a vector (or scalar) of right x positions

ytop

a vector (or scalar) of top y positions

...

par options for plot

Examples

1
colramp.legend(col1="red", col2="blue", ncol=length(PB$E), 2.5, 3.5, 2.7, 4.5)

duplisea/ccca documentation built on April 17, 2021, 2:31 a.m.