yaxis2.f: Create a second y axis on the right side

Description Usage

View source: R/helper.functions.r

Description

Create a second y axis on the right side

Usage

1
yaxis2.f(x, y, ylabel = "2ndyaxis", cex = 0.75, ...)

duplisea/ccca documentation built on April 17, 2021, 2:31 a.m.