View source: R/climate.scenario.functions.r
A function calculated P/B for projection based on the climate scenario. It samples the residuals of the fitted relationship and adds one to each draw
1 | PB.for.projection.f(PvsE, Eproj, add.residuals = add.resids)
|
PvsE |
The fitted PB vs E model object |
Eproj |
The matrix of E values for the projection. From running Eprojgamma.f |
add.residuals |
if yes=1, no=0. DO NOT USE ANY OTHER VALUE!! This formulation is faster because it avoids an if statement |
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.